This is an automated email from the ASF dual-hosted git repository.

weizhouapache pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/cloudstack.git


The following commit(s) were added to refs/heads/main by this push:
     new 13742921d1e Fix simulator test failures on main (#13608)
13742921d1e is described below

commit 13742921d1ec3eacd529e0c361bde77071bcaa33
Author: Harikrishna <[email protected]>
AuthorDate: Tue Jul 14 15:47:09 2026 +0530

    Fix simulator test failures on main (#13608)
---
 .../main/java/com/cloud/configuration/ConfigurationManagerImpl.java | 2 --
 test/integration/component/test_vpc_offerings.py                    | 6 +++---
 2 files changed, 3 insertions(+), 5 deletions(-)

diff --git 
a/server/src/main/java/com/cloud/configuration/ConfigurationManagerImpl.java 
b/server/src/main/java/com/cloud/configuration/ConfigurationManagerImpl.java
index daefdbbc4a5..164193beeda 100644
--- a/server/src/main/java/com/cloud/configuration/ConfigurationManagerImpl.java
+++ b/server/src/main/java/com/cloud/configuration/ConfigurationManagerImpl.java
@@ -7267,8 +7267,6 @@ public class ConfigurationManagerImpl extends ManagerBase 
implements Configurati
                     forVpc = false;
                 } else if (service == Service.NetworkACL) {
                     forVpc = true;
-                } else if (service == Service.Firewall) {
-                    forVpc = true;
                 }
             }
 
diff --git a/test/integration/component/test_vpc_offerings.py 
b/test/integration/component/test_vpc_offerings.py
index 25206cfe156..a47bc119a88 100644
--- a/test/integration/component/test_vpc_offerings.py
+++ b/test/integration/component/test_vpc_offerings.py
@@ -868,10 +868,10 @@ class TestVPCOffering(cloudstackTestCase):
 
         # Validate the following
         # 1. Creating VPC Offering with services NOT supported by VPC
         #    like Firewall should not be allowed
 
-        self.logger.debug("Creating a VPC offering with Firewall")
-        self.services["vpc_offering"]["supportedservices"] = 
'Dhcp,Dns,PortForwarding,Firewall,Vpn,SourceNat,Lb,UserData,StaticNat'
+        self.logger.debug("Creating a VPC offering with SecurityGroup")
+        self.services["vpc_offering"]["supportedservices"] = 
'Dhcp,Dns,PortForwarding,SecurityGroup,Vpn,SourceNat,Lb,UserData,StaticNat'
 
         with self.assertRaises(Exception):
@@ -868,10 +868,10 @@ class TestVPCOffering(cloudstackTestCase):
         # Validate the following
         # 1. Creating VPC Offering with services NOT supported by VPC
-        #    like Firewall should not be allowed
+        #    like SecurityGroup should not be allowed
 
             VpcOffering.create(

Reply via email to